import React from 'react';
import { StyleSheet, TouchableOpacity, View, Text } from 'react-native';
import Icon from 'react-native-vector-icons/MaterialCommunityIcons';
import { hitSlop } from '../../constants';
import { useTheme } from '../../contexts/theme';
const defaultIconSize = 26;
export let ButtonLocation = /*#__PURE__*/function (ButtonLocation) {
  ButtonLocation[ButtonLocation["Left"] = 0] = "Left";
  ButtonLocation[ButtonLocation["Right"] = 1] = "Right";
  return ButtonLocation;
}({});
const HeaderButton = _ref => {
  let {
    buttonLocation,
    icon,
    text,
    accessibilityLabel,
    testID,
    onPress
  } = _ref;
  const {
    ColorPallet,
    TextTheme
  } = useTheme();
  const style = StyleSheet.create({
    container: {
      flexDirection: 'row',
      alignItems: 'center',
      marginRight: buttonLocation === ButtonLocation.Left ? 0 : 15,
      marginLeft: buttonLocation === ButtonLocation.Right ? 0 : 15,
      minWidth: defaultIconSize,
      minHeight: defaultIconSize
    },
    title: {
      ...TextTheme.label,
      color: ColorPallet.brand.headerText,
      marginRight: 4
    }
  });
  const layoutForButtonLocation = buttonLocation => {
    switch (buttonLocation) {
      case ButtonLocation.Left:
        return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Icon, {
          name: icon,
          size: defaultIconSize,
          color: ColorPallet.brand.headerIcon
        }), text && /*#__PURE__*/React.createElement(Text, {
          style: [style.title]
        }, text));
      case ButtonLocation.Right:
        return /*#__PURE__*/React.createElement(React.Fragment, null, text && /*#__PURE__*/React.createElement(Text, {
          style: [style.title]
        }, text), /*#__PURE__*/React.createElement(Icon, {
          name: icon,
          size: defaultIconSize,
          color: ColorPallet.brand.headerIcon
        }));
    }
  };
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    accessibilityLabel: accessibilityLabel,
    accessibilityRole: 'button',
    testID: testID,
    onPress: onPress,
    hitSlop: hitSlop
  }, /*#__PURE__*/React.createElement(View, {
    style: style.container
  }, layoutForButtonLocation(buttonLocation)));
};
export default HeaderButton;
//# sourceMappingURL=HeaderButton.js.map